@@ -810,7 +810,7 @@ class account():
             if (self.avatars.get_value(item, 3) == name):
                 return self.avatars.get_value(item, 0)
             item = self.avatars.iter_next(item)
-        return gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/tweet.png")
+        return gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
 
     def set_pic_for_id(self, id, name, url):
         return self.set_pix(id + ".jpg", url, id, name)
@@ -859,7 +859,7 @@ class account():
                 print "io error"
                 print e
                 print "failed to find avatar for user: " + filename
-                pixbuf = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/tweet.png")
+                pixbuf = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
         return pixbuf
 
     def retrieve_avatar(self, url, filename):
@@ -880,12 +880,12 @@ class account():
         except IOError, e:
             print e
             print "failed to retreive picture for " + url + " : " + filename
-            pixbuf = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/tweet.png")
+            pixbuf = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
             return pixbuf, False
         except UnicodeError, e2:
             print e2
             print "failed to retreive picture for " + url + " : " + filename
-            pixbuf = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/tweet.png")
+            pixbuf = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
             return pixbuf, False
         return pixbuf, True
 
